use std::collections::HashMap;

#[derive(Debug)]
pub enum RawQuestion {
    Plain(PlainQuestion),
    Formula(FormulaQuestion),
}

#[derive(Debug)]
pub struct PlainQuestion {
    pub stem: String,
    pub answer: String,
    pub alternatives: Vec<String>,
}

#[derive(Debug)]
pub struct FormulaQuestion {
    pub stem: String,
    pub answer: String,
    pub variables: Vec<Variable>,
    pub parameters: HashMap<String, f32>,
}

#[derive(Debug)]
pub struct Variable {
    pub name: String,
    pub min: i32,
    pub max: i32,
}

#[derive(Debug)]
pub struct Student {
    pub name: String,
    pub registration: String,
}

#[derive(Debug)]
pub struct ExamHeader {
    pub institute: String,
    pub departament: String,
    pub subject: String,
    pub professor: String,
    pub date: String,
    pub instructions: String
}

#[derive(Debug, Clone)]
pub struct Question {
    pub stem: String,
    pub alternatives: Vec<String>,
    pub answer: u8,
}

#[derive(Debug)]
pub struct Config {
    pub octave_bin: String,
    pub latex_bin: String,
    pub ghostscript_bin: String,
    pub n_alternatives: u8,
}

#[derive(Debug)]
pub struct Exam {
    pub student: Student,
    pub questions: Vec<Question>,
}
