extern crate pbr;
extern crate rand;
extern crate yaml_rust;
mod iolaus;
mod parsers;
mod processors;
mod output;

use iolaus::data_types::{Config, ExamHeader, RawQuestion, Student};
use std::env;
use std::path::PathBuf;

fn main() {
    let mut base_path = env::current_dir().expect("Erro #0001");
    base_path.push("amostra");

    let mut output_path = base_path.clone();
    output_path.push("saida");
    std::fs::create_dir_all(output_path).expect("Erro #0002");

    let (config, exam_header, students, raw_questions) = parse(&base_path);
    let questions = processors::questions::get(raw_questions, students.len(), &config);
    let n_questions = questions.len();
    let exams = processors::exams::process(students, questions);
    output::exam_tex::create(&base_path, &exam_header, &exams, n_questions);
    output::answers_tex::create(&base_path, &exam_header, &exams);
    output::pdf::create(&base_path, exams.len(), &config);
}

fn parse(base_path: &PathBuf) -> (Config, ExamHeader, Vec<Student>, Vec<RawQuestion>) {
    let mut config_path = base_path.clone();
    let mut exam_header_path = base_path.clone();
    let mut students_path = base_path.clone();
    let mut questions_path = base_path.clone();
    config_path.push("config.yml");
    exam_header_path.push("exame.yml");
    students_path.push("alunos.csv");
    questions_path.push("perguntas");

    let config = parsers::config::get(&config_path);
    let exam_header = parsers::exam_header::get(&exam_header_path);
    let students = parsers::students::get(&students_path);
    let raw_questions = parsers::questions::get(&questions_path, config.n_alternatives);
    (config, exam_header, students, raw_questions)
}
