use iolaus::data_types::{Exam, ExamHeader};
use iolaus::utils;
use std::path::PathBuf;

pub fn create(base_path: &PathBuf, exam_header: &ExamHeader, exams: &Vec<Exam>) {
    let (answers_doc_template, answers_item_template) = read_templates(base_path);
    let mut output_path = base_path.clone();
    output_path.push("saida");

    let letters = ["A", "B", "C", "D", "E"];
    let mut all_answers = String::new();

    for exam in exams {
        let mut tpl = answers_item_template.clone();
        tpl = tpl.replace("@{nome_aluno}", &exam.student.name);
        let mut answers = String::new();
        let mut counter = 1;
        for question in &exam.questions {
            answers =
                answers + &format!("{} - {}\\\\\n", counter, letters[question.answer as usize]);
            counter = counter + 1;
        }
        tpl = tpl.replace("@{respostas}", &answers);
        all_answers = all_answers + &tpl;
    }
    let mut answers_doc = answers_doc_template.replace("@{gabarito}", &all_answers);
    answers_doc = answers_doc.replace("@{instituicao}", &exam_header.institute);
    answers_doc = answers_doc.replace("@{departamento}", &exam_header.departament);
    answers_doc = answers_doc.replace("@{professor}", &exam_header.professor);
    answers_doc = answers_doc.replace("@{disciplina}", &exam_header.subject);
    answers_doc = answers_doc.replace("@{data}", &exam_header.date);
    output_path.push("gabarito.tex");
    utils::write_file(&output_path, answers_doc);
}

fn read_templates(base_path: &PathBuf) -> (String, String) {
    let mut template_path = base_path.clone();
    template_path.push("templates");

    let mut answers_doc_path = template_path.clone();
    let mut answers_item_path = template_path.clone();
    answers_doc_path.push("respostas.tex");
    answers_item_path.push("respostas-item.tex");

    let answers_doc = utils::read_file_content(&answers_doc_path);
    let answers_item = utils::read_file_content(&answers_item_path);

    (answers_doc, answers_item)
}
