use iolaus::data_types::{Exam, ExamHeader, Question};
use iolaus::utils;
use std::path::PathBuf;

pub fn create(
    base_path: &PathBuf,
    exam_header: &ExamHeader,
    exams: &Vec<Exam>,
    n_questions: usize,
) {
    let (exam_template, question_template, alternative_template, bubbles_template) =
        read_templates(base_path);
    let mut output_path = base_path.clone();
    output_path.push("saida");
    let mut counter = 1;
    for exam in exams {
        let mut tpl = exam_template.clone();
        tpl = tpl.replace("@{instituicao}", &exam_header.institute);
        tpl = tpl.replace("@{departamento}", &exam_header.departament);
        tpl = tpl.replace("@{disciplina}", &exam_header.subject);
        tpl = tpl.replace("@{professor}", &exam_header.professor);
        tpl = tpl.replace("@{data}", &exam_header.date);
        tpl = tpl.replace("@{instrucoes}", &exam_header.instructions);
        tpl = tpl.replace("@{nome_aluno}", &exam.student.name);
        tpl = tpl.replace("@{matricula}", &exam.student.registration);
        tpl = tpl.replace(
            "@{bubbles}",
            &create_bubbles(&bubbles_template, n_questions),
        );
        tpl = tpl.replace(
            "@{questoes}",
            &create_questions(&question_template, &alternative_template, &exam.questions),
        );

        let filename = format!("prova{:>03}.tex", counter);
        let mut file_path = output_path.clone();
        file_path.push(filename);
        utils::write_file(&file_path, tpl);
        counter = counter + 1;
    }
}

fn create_bubbles(bubbles_template: &String, n_questions: usize) -> String {
    let mut bubbles = String::new();
    for i in 1..=n_questions {
        bubbles = bubbles + &bubbles_template.replace("@{numero_questao}", &format!("{}", i));
    }
    bubbles
}

fn create_questions(
    question_template: &String,
    alternative_template: &String,
    questions: &Vec<Question>,
) -> String {
    let mut questions_text = String::new();
    let mut counter = 1;
    for question in questions {
        let mut question_tpl = question_template.clone();
        question_tpl = question_tpl.replace("@{numero}", &counter.to_string());
        question_tpl = question_tpl.replace("@{questao}", &question.stem);
        let mut alternatives_text = String::new();
        for alternative in &question.alternatives {
            let alternative_text = alternative_template.replace("@{opcao}", &alternative);
            alternatives_text = alternatives_text + &alternative_text;
        }
        question_tpl = question_tpl.replace("@{opcoes}", &alternatives_text);
        questions_text = questions_text + &question_tpl;
        counter = counter + 1
    }
    questions_text
}

fn read_templates(base_path: &PathBuf) -> (String, String, String, String) {
    let mut template_path = base_path.clone();
    template_path.push("templates");

    let mut exam_template_path = template_path.clone();
    let mut alternative_template_path = template_path.clone();
    let mut option_template_path = template_path.clone();
    let mut bubbles_template_path = template_path.clone();
    exam_template_path.push("prova.tex");
    alternative_template_path.push("pergunta.tex");
    option_template_path.push("opcao.tex");
    bubbles_template_path.push("bubbles.tex");

    let exam_template = utils::read_file_content(&exam_template_path);
    let alternative_template = utils::read_file_content(&alternative_template_path);
    let option_template = utils::read_file_content(&option_template_path);
    let bubbles_template = utils::read_file_content(&bubbles_template_path);

    (
        exam_template,
        alternative_template,
        option_template,
        bubbles_template,
    )
}
