use iolaus::data_types::Config;
use pbr::ProgressBar;
use std::{io, fs, env};
use std::io::prelude::*;
use std::path::PathBuf;
use std::process::Command;

pub fn create(base_path: &PathBuf, n_files: usize, config: &Config) {
    let mut output_path = base_path.clone();
    output_path.push("saida");
    env::set_current_dir(&output_path).expect("Erro #0701");

    let mut gs_command = Command::new(&config.ghostscript_bin);
    gs_command.arg("-dBATCH");
    gs_command.arg("-dNOPAUSE");
    gs_command.arg("-q");
    gs_command.arg("-sDEVICE=pdfwrite");
    gs_command.arg("-sOutputFile=../provas.pdf");

    let mut pb = ProgressBar::new((n_files * 3) as u64);
    pb.format("╢▌▌░╟");
    println!("\nCriando PDFs");

    for i in 1..=n_files {
        let filename = format!("prova{:>03}.tex", i);
        gs_command.arg(format!("prova{:>03}.pdf", i));
        for _ in 0..3 {
            let output = Command::new(&config.latex_bin)
                .arg("-interaction=nonstopmode")
                .arg(&filename)
                .output()
                .expect("Não foi possível executar o latex");

            if !output.status.success() {
                panic!("Erro ao executar o latex:\n{}", filename);
            }
            pb.inc();
        }
    }
    pb.finish_print("\n");

    print!("\nGerando gabarito... ");
    io::stdout()
        .flush()
        .ok()
        .expect("Could not flush stdout #1");

    let output = Command::new(&config.latex_bin)
        .arg("-interaction=nonstopmode")
        .arg("gabarito.tex")
        .output()
        .expect("Não foi possível executar o latex");

    if !output.status.success() {
        panic!("Erro ao executar o latex:\ngabarito.tex");
    }

    fs::copy("gabarito.pdf", "../gabarito.pdf").expect("Não foi possível copiar o PDF");

    println!("pronto!");

    print!("\nUnindo PDFs... ");
    io::stdout()
        .flush()
        .ok()
        .expect("Could not flush stdout #2");

    let output = gs_command
        .output()
        .expect("Não foi possível executar o GhostScript");

    if !output.status.success() {
        panic!("Erro ao unir os PDFs: {:#?}", output);
    }

    println!("pronto!");
}
