extern crate yaml_rust;

use iolaus::data_types::Config;
use iolaus::utils;
use std::path::Path;
use yaml_rust::{Yaml, YamlLoader};

pub fn get(path: &Path) -> Config {
    let file_path = path.to_str().expect("Erro #0501");
    let content = utils::read_file_content(path);
    let docs = match YamlLoader::load_from_str(&content) {
        Err(_) => panic!("{}: formato YML inválido", file_path),
        Ok(docs) => docs,
    };
    let doc = &docs[0];

    let octave_path = parse_string("octave_path", doc, file_path);
    let latex_path = parse_string("octave_path", doc, file_path);
    let ghostscript_path = parse_string("ghostscript_path", doc, file_path);
    let octave_bin = octave_path + "/octave-cli";
    let latex_bin = latex_path + "/pdflatex";
    let ghostscript_bin = ghostscript_path + "/gs";

    Config {
        octave_bin,
        latex_bin,
        ghostscript_bin,
        n_alternatives: 5
    }
}

fn parse_string(parameter: &str, doc: &Yaml, file_path: &str) -> String {
    match doc[parameter].as_str() {
        Some(item) => item.to_string(),
        None => panic!("{}: {} não especificado(a)", file_path, parameter),
    }
}