use iolaus::data_types::{Config, FormulaQuestion, PlainQuestion, Question, RawQuestion};
use pbr::ProgressBar;
use processors::{formula_question, plain_question};
use std::io::Stdout;

pub fn get(
    raw_questions: Vec<RawQuestion>,
    n_students: usize,
    config: &Config,
) -> Vec<Vec<Question>> {
    let mut questions = Vec::new();
    let mut pb = ProgressBar::new((raw_questions.len() * n_students) as u64);
    pb.format("╢▌▌░╟");
    println!("\nCriando questões");

    for raw_question in raw_questions {
        questions.push(match raw_question {
            RawQuestion::Plain(q) => process_plain(q, n_students, config, &mut pb),
            RawQuestion::Formula(q) => process_formula(q, n_students, config, &mut pb),
        });
    }
    pb.finish_print("\n");
    questions
}

fn process_plain(
    raw_question: PlainQuestion,
    n_students: usize,
    config: &Config,
    pb: &mut ProgressBar<Stdout>,
) -> Vec<Question> {
    let mut questions = Vec::new();
    for _ in 0..n_students {
        questions.push(plain_question::process(&raw_question, config));
        pb.inc();
    }
    questions
}

fn process_formula(
    raw_question: FormulaQuestion,
    n_students: usize,
    config: &Config,
    pb: &mut ProgressBar<Stdout>,
) -> Vec<Question> {
    let mut questions = Vec::new();
    for _ in 0..n_students {
        questions.push(formula_question::process(&raw_question, config));
        pb.inc();
    }
    questions
}
